@@ -59,7 +59,7 @@ import javax.tools.JavaFileObject;
 import javax.tools.StandardJavaFileManager;
 import javax.tools.StandardLocation;
 import org.eclipse.jdt.internal.compiler.tool.EclipseCompiler;
-import org.checkerframework.checker.nullness.qual.Nullable;
+import org.jspecify.annotations.Nullable;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
@@ -70,10 +70,9 @@ import org.junit.runners.Parameterized;
 import org.junit.runners.model.Statement;
 
 /**
- * Tests that the {@link Overrides} class has behaviour consistent with javac. We test this in
- * two ways: once with {@link Overrides.ExplicitOverrides} using javac's own {@link Elements} and
- * {@link Types}, and once with it using the version of those objects from the Eclipse compiler
- * (ecj).
+ * Tests that the {@link Overrides} class has behaviour consistent with javac. We test this in two
+ * ways: once with {@link Overrides.ExplicitOverrides} using javac's own {@link Elements} and {@link
+ * Types}, and once with it using the version of those objects from the Eclipse compiler (ecj).
  *
  * @author emcmanus@google.com (Éamonn McManus)
  */
@@ -440,6 +439,7 @@ public class OverridesTest {
   // it also inherits it from Collection<E>.
 
   private interface XCollection<E> {
+    @SuppressWarnings("unused")
     boolean add(E e);
   }
 
@@ -576,9 +576,9 @@ public class OverridesTest {
 
   private void assertTypeListsEqual(@Nullable List<TypeMirror> actual, List<TypeMirror> expected) {
     assertThat(actual)
-      .comparingElementsUsing(Correspondence.from(typeUtils::isSameType, "is same type as"))
-      .containsExactlyElementsIn(expected)
-      .inOrder();
+        .comparingElementsUsing(Correspondence.from(typeUtils::isSameType, "is same type as"))
+        .containsExactlyElementsIn(expected)
+        .inOrder();
   }
 
   // TODO(emcmanus): replace this with something from compile-testing when that's available.
