@@ -18,12 +18,13 @@ package com.google.auto.value.processor;
 import static com.google.auto.common.GeneratedAnnotations.generatedAnnotation;
 import static com.google.auto.common.MoreElements.getLocalAndInheritedMethods;
 import static com.google.auto.common.MoreElements.getPackage;
-import static com.google.auto.common.MoreStreams.toImmutableList;
-import static com.google.auto.common.MoreStreams.toImmutableMap;
-import static com.google.auto.common.MoreStreams.toImmutableSet;
 import static com.google.auto.value.processor.AutoValueProcessor.OMIT_IDENTIFIERS_OPTION;
 import static com.google.auto.value.processor.ClassNames.AUTO_ANNOTATION_NAME;
 import static com.google.auto.value.processor.ClassNames.AUTO_BUILDER_NAME;
+import static com.google.common.collect.ImmutableList.toImmutableList;
+import static com.google.common.collect.ImmutableMap.toImmutableMap;
+import static com.google.common.collect.ImmutableSet.toImmutableSet;
+import static java.math.RoundingMode.CEILING;
 import static java.util.stream.Collectors.joining;
 import static java.util.stream.Collectors.toMap;
 import static javax.lang.model.util.ElementFilter.constructorsIn;
@@ -40,6 +41,7 @@ import com.google.common.base.Ascii;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
+import com.google.common.math.IntMath;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.io.UncheckedIOException;
@@ -200,12 +202,7 @@ public class AutoBuilderProcessor extends AutoValueishProcessor {
     ImmutableMap<String, String> propertyToGetterName =
         propertyToGetterName(executable, autoBuilderType);
     AutoBuilderTemplateVars vars = new AutoBuilderTemplateVars();
-    vars.props =
-        propertySet(
-            executable,
-            propertyToGetterName,
-            propertyInitializers,
-            nullables);
+    vars.props = propertySet(executable, propertyToGetterName, propertyInitializers, nullables);
     builder.defineVars(vars, classifier);
     vars.identifiers = !processingEnv.getOptions().containsKey(OMIT_IDENTIFIERS_OPTION);
     String generatedClassName = generatedClassName(autoBuilderType, "AutoBuilder_");
@@ -219,8 +216,7 @@ public class AutoBuilderProcessor extends AutoValueishProcessor {
             .orElseGet(executable::invoke);
     vars.toBuilderConstructor = !propertyToGetterName.isEmpty();
     vars.toBuilderMethods = ImmutableList.of();
-    defineSharedVarsForType(
-        autoBuilderType, ImmutableSet.of(), nullables, vars);
+    defineSharedVarsForType(autoBuilderType, ImmutableSet.of(), nullables, vars);
     String text = vars.toText();
     text = TypeEncoder.decode(text, processingEnv, vars.pkg, autoBuilderType.asType());
     text = Reformatter.fixup(text);
@@ -250,7 +246,7 @@ public class AutoBuilderProcessor extends AutoValueishProcessor {
         .map(Element::asType)
         .map(typeUtils()::erasure)
         .forEach(constructorParameters::add);
-    int bitmaskCount = (executable.optionalParameterCount() + 31) / 32;
+    int bitmaskCount = IntMath.divide(executable.parameters().size(), 32, CEILING);
     constructorParameters.addAll(
         Collections.nCopies(bitmaskCount, typeUtils().getPrimitiveType(TypeKind.INT)));
     String marker = "kot".concat("lin.jvm.internal.DefaultConstructorMarker"); // defeat shading
@@ -271,9 +267,9 @@ public class AutoBuilderProcessor extends AutoValueishProcessor {
 
   private Optional<String> maybeForwardingClass(
       TypeElement autoBuilderType, Executable executable) {
-    return executable.optionalParameterCount() == 0
-        ? Optional.empty()
-        : Optional.of(generatedClassName(autoBuilderType, "AutoBuilderBridge_"));
+    return executable.hasOptionalParameters()
+        ? Optional.of(generatedClassName(autoBuilderType, "AutoBuilderBridge_"))
+        : Optional.empty();
   }
 
   private ImmutableSet<Property> propertySet(
@@ -284,8 +280,7 @@ public class AutoBuilderProcessor extends AutoValueishProcessor {
     // Fix any parameter names that are reserved words in Java. Java source code can't have
     // such parameter names, but Kotlin code might, for example.
     Map<VariableElement, String> identifiers =
-        executable.parameters().stream()
-            .collect(toMap(v -> v, v -> v.getSimpleName().toString()));
+        executable.parameters().stream().collect(toMap(v -> v, v -> v.getSimpleName().toString()));
     fixReservedIdentifiers(identifiers);
     return executable.parameters().stream()
         .map(
@@ -322,7 +317,7 @@ public class AutoBuilderProcessor extends AutoValueishProcessor {
     return new Property(
         name,
         identifier,
-        TypeEncoder.encode(type),
+        TypeEncoder.encodeWithAnnotations(type),
         new AnnotatedTypeMirror(type),
         nullableAnnotation,
         nullables,
@@ -377,8 +372,8 @@ public class AutoBuilderProcessor extends AutoValueishProcessor {
    * <p>The return type of each getter method must match the type of the corresponding parameter
    * exactly. This will always be true for our principal use cases, Java records and Kotlin data
    * classes. For other use cases, we may in the future accept getters where we know how to convert,
-   * for example if the getter has type {@code ImmutableList<Baz>} and the parameter has type
-   * {@code Baz[]}. We already have similar logic for the parameter types of builder setters.
+   * for example if the getter has type {@code ImmutableList<Baz>} and the parameter has type {@code
+   * Baz[]}. We already have similar logic for the parameter types of builder setters.
    */
   private ImmutableMap<String, String> propertyToGetterName(
       Executable executable, TypeElement autoBuilderType) {
@@ -521,9 +516,7 @@ public class AutoBuilderProcessor extends AutoValueishProcessor {
   }
 
   private String executableListString(List<Executable> executables) {
-    return executables.stream()
-        .map(Object::toString)
-        .collect(joining("\n  ", "  ", ""));
+    return executables.stream().map(Object::toString).collect(joining("\n  ", "  ", ""));
   }
 
   private boolean executableMatches(
@@ -566,9 +559,9 @@ public class AutoBuilderProcessor extends AutoValueishProcessor {
       case PUBLIC:
         return true;
       case PROTECTED:
-        // We care about whether the constructor is visible from the generated class. The generated
-        // class is never going to be a subclass of the class containing the constructor, so
-        // protected and default access are equivalent.
+      // We care about whether the constructor is visible from the generated class. The generated
+      // class is never going to be a subclass of the class containing the constructor, so
+      // protected and default access are equivalent.
       case DEFAULT:
         return getPackage(element).equals(fromPackage);
       default:
@@ -689,8 +682,7 @@ public class AutoBuilderProcessor extends AutoValueishProcessor {
   }
 
   private static Property annotationBuilderProperty(
-      ExecutableElement annotationMethod,
-      Nullables nullables) {
+      ExecutableElement annotationMethod, Nullables nullables) {
     String name = annotationMethod.getSimpleName().toString();
     TypeMirror type = annotationMethod.getReturnType();
     return new Property(
