@@ -16,9 +16,9 @@
 package com.google.auto.value.processor;
 
 import static com.google.auto.common.MoreElements.getLocalAndInheritedMethods;
-import static com.google.auto.common.MoreStreams.toImmutableList;
 import static com.google.auto.value.processor.ClassNames.AUTO_VALUE_NAME;
 import static com.google.common.base.Preconditions.checkState;
+import static com.google.common.collect.ImmutableList.toImmutableList;
 import static com.google.common.collect.Sets.difference;
 import static com.google.common.collect.Sets.intersection;
 import static java.util.Comparator.naturalOrder;
@@ -500,10 +500,7 @@ public class AutoValueProcessor extends AutoValueishProcessor {
         propertyMethodAnnotationMap(type, propertyMethods);
     vars.props =
         propertySet(
-            propertyMethodsAndTypes,
-            annotatedPropertyFields,
-            annotatedPropertyMethods,
-            nullables);
+            propertyMethodsAndTypes, annotatedPropertyFields, annotatedPropertyMethods, nullables);
     // Check for @AutoValue.Builder and add appropriate variables if it is present.
     maybeBuilder.ifPresent(
         builder -> {
