@@ -20,11 +20,11 @@ import static com.google.auto.common.GeneratedAnnotations.generatedAnnotation;
 import static com.google.auto.common.MoreElements.asType;
 import static com.google.auto.common.MoreElements.getPackage;
 import static com.google.auto.common.MoreElements.isAnnotationPresent;
-import static com.google.auto.common.MoreStreams.toImmutableList;
-import static com.google.auto.common.MoreStreams.toImmutableMap;
-import static com.google.auto.common.MoreStreams.toImmutableSet;
 import static com.google.auto.value.processor.ClassNames.AUTO_VALUE_PACKAGE_NAME;
 import static com.google.auto.value.processor.ClassNames.COPY_ANNOTATIONS_NAME;
+import static com.google.common.collect.ImmutableList.toImmutableList;
+import static com.google.common.collect.ImmutableMap.toImmutableMap;
+import static com.google.common.collect.ImmutableSet.toImmutableSet;
 import static com.google.common.collect.Iterables.getOnlyElement;
 import static com.google.common.collect.Sets.union;
 import static java.util.stream.Collectors.joining;
@@ -1143,8 +1143,19 @@ abstract class AutoValueishProcessor extends AbstractProcessor {
     @SuppressWarnings("unchecked")
     List<AnnotationValue> excludedClasses =
         (List<AnnotationValue>) getAnnotationValue(maybeAnnotation.get(), "exclude").getValue();
+    // It turns out that if you write `@AutoValue.CopyAnnotations(exclude = {Missing.class})`, where
+    // `Missing` is a class that does not exist, then javac will represent it as a String in the
+    // AnnotationValue, rather than an ErrorType as you might expect. So we filter out anything that
+    // is not a DeclaredType. (ErrorType *is* a DeclaredType.) Presumably you'll get a compilation
+    // error because of the missing class. If another compiler uses ErrorType instead of String,
+    // then we'll just add that ErrorType to the returned TypeMirrorSet here, where it will
+    // presumably be ignored, or perhaps match the ErrorType for `@Missing` somewhere else in the
+    // code.
+    // This is a pretty obscure case so our main concern here is to avoid a ClassCastException.
     return excludedClasses.stream()
-        .map(annotationValue -> (DeclaredType) annotationValue.getValue())
+        .map(AnnotationValue::getValue)
+        .filter(DeclaredType.class::isInstance)
+        .map(DeclaredType.class::cast)
         .collect(toCollection(TypeMirrorSet::new));
   }
 
