@@ -16,11 +16,11 @@
 package com.google.auto.value.processor;
 
 import static com.google.auto.common.MoreElements.getLocalAndInheritedMethods;
-import static com.google.auto.common.MoreStreams.toImmutableSet;
 import static com.google.auto.value.processor.AutoValueishProcessor.hasAnnotationMirror;
 import static com.google.auto.value.processor.AutoValueishProcessor.hasVisibleNoArgConstructor;
 import static com.google.auto.value.processor.AutoValueishProcessor.nullableAnnotationFor;
 import static com.google.auto.value.processor.ClassNames.AUTO_VALUE_BUILDER_NAME;
+import static com.google.common.collect.ImmutableSet.toImmutableSet;
 import static com.google.common.collect.Sets.immutableEnumSet;
 import static java.util.stream.Collectors.toList;
 import static java.util.stream.Collectors.toSet;
@@ -221,15 +221,15 @@ class BuilderSpec {
      * parameters must be the same as those of the {@code @AutoValue} class. Here's a correct
      * example:
      *
-     * <pre>
-     * {@code @AutoValue abstract class Foo<A extends Number, B> {
+     * <pre>{@code
+     * @AutoValue abstract class Foo<A extends Number, B> {
      *   abstract int someProperty();
      *
      *   abstract Builder<A, B> toBuilder();
      *
      *   interface Builder<A extends Number, B> {...}
-     * }}
-     * </pre>
+     * }
+     * }</pre>
      *
      * <p>We currently impose that there cannot be more than one such method.
      */
@@ -362,8 +362,7 @@ class BuilderSpec {
               .filter(p -> !p.hasDefault())
               .filter(p -> !vars.builderPropertyBuilders.containsKey(p.getName()))
               .collect(toImmutableSet());
-      vars.builderRequiredProperties =
-          BuilderRequiredProperties.of(vars.props, requiredProperties);
+      vars.builderRequiredProperties = BuilderRequiredProperties.of(vars.props, requiredProperties);
     }
   }
 
@@ -462,7 +461,7 @@ class BuilderSpec {
     private final String nullableAnnotation;
     private final Copier copier;
 
-    PropertySetter(ExecutableElement setter, TypeMirror parameterType, Copier copier) {
+    PropertySetter(ExecutableElement setter, AnnotatedTypeMirror parameterType, Copier copier) {
       this.setter = setter;
       this.copier = copier;
       this.access = SimpleMethod.access(setter);
@@ -470,7 +469,8 @@ class BuilderSpec {
       primitiveParameter = parameterType.getKind().isPrimitive();
       this.parameterTypeString = parameterTypeString(setter, parameterType);
       VariableElement parameterElement = Iterables.getOnlyElement(setter.getParameters());
-      Optional<String> maybeNullable = nullableAnnotationFor(parameterElement, parameterType);
+      Optional<String> maybeNullable =
+          nullableAnnotationFor(parameterElement, parameterType.getType());
       this.nullableAnnotation = maybeNullable.orElse("");
     }
 
@@ -478,9 +478,10 @@ class BuilderSpec {
       return setter;
     }
 
-    private static String parameterTypeString(ExecutableElement setter, TypeMirror parameterType) {
+    private static String parameterTypeString(
+        ExecutableElement setter, AnnotatedTypeMirror parameterType) {
       if (setter.isVarArgs()) {
-        TypeMirror componentType = MoreTypes.asArray(parameterType).getComponentType();
+        TypeMirror componentType = MoreTypes.asArray(parameterType.getType()).getComponentType();
         // This is a bit ugly. It's OK to annotate just the component type, because if it is
         // say `@Nullable String` then we will end up with `@Nullable String...`. Unlike the
         // normal array case, we can't have the situation where the array itself is annotated;
