@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017 Google, Inc.
+ * Copyright 2017 Google LLC
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,12 +17,17 @@ package com.google.auto.value.processor;
 
 import static com.google.common.base.Preconditions.checkArgument;
 import static com.google.common.base.Preconditions.checkState;
+import static java.util.stream.Collectors.toList;
 
 import com.google.auto.common.MoreElements;
 import com.google.auto.common.MoreTypes;
+import com.google.auto.value.processor.MissingTypes.MissingTypeException;
+import com.google.common.collect.ImmutableList;
+import com.google.common.collect.ImmutableSet;
 import java.util.List;
 import java.util.OptionalInt;
 import java.util.Set;
+import java.util.function.Function;
 import javax.annotation.processing.ProcessingEnvironment;
 import javax.lang.model.element.AnnotationMirror;
 import javax.lang.model.element.TypeElement;
@@ -69,8 +74,6 @@ final class TypeEncoder {
   private static final EncodingTypeVisitor ENCODING_TYPE_VISITOR = new EncodingTypeVisitor();
   private static final RawEncodingTypeVisitor RAW_ENCODING_TYPE_VISITOR =
       new RawEncodingTypeVisitor();
-  private static final AnnotatedEncodingTypeVisitor ANNOTATED_ENCODING_TYPE_VISITOR =
-      new AnnotatedEncodingTypeVisitor();
 
   /**
    * Returns the encoding for the given type, where class names are marked by special tokens. The
@@ -96,8 +99,95 @@ final class TypeEncoder {
    * covers the details of annotation encoding.
    */
   static String encodeWithAnnotations(TypeMirror type) {
+    return encodeWithAnnotations(type, ImmutableList.of(), ImmutableSet.of());
+  }
+
+  /**
+   * Encodes the given type and its type annotations. The class comment for {@link TypeEncoder}
+   * covers the details of annotation encoding.
+   */
+  static String encodeWithAnnotations(AnnotatedTypeMirror type) {
+    return encodeWithAnnotations(type, ImmutableList.of(), ImmutableSet.of());
+  }
+
+  /**
+   * Encodes the given type and its type annotations. The class comment for {@link TypeEncoder}
+   * covers the details of annotation encoding.
+   *
+   * @param extraAnnotations additional type annotations to include with the type
+   */
+  static String encodeWithAnnotations(
+      TypeMirror type, ImmutableList<AnnotationMirror> extraAnnotations) {
+    return encodeWithAnnotations(type, extraAnnotations, ImmutableSet.of());
+  }
+
+  /**
+   * Encodes the given type and its type annotations. The class comment for {@link TypeEncoder}
+   * covers the details of annotation encoding.
+   *
+   * @param extraAnnotations additional type annotations to include with the type
+   */
+  static String encodeWithAnnotations(
+      AnnotatedTypeMirror type, ImmutableList<AnnotationMirror> extraAnnotations) {
+    return encodeWithAnnotations(type, extraAnnotations, ImmutableSet.of());
+  }
+
+  /**
+   * Encodes the given type and its type annotations. The class comment for {@link TypeEncoder}
+   * covers the details of annotation encoding.
+   *
+   * @param extraAnnotations additional type annotations to include with the type
+   * @param excludedAnnotationTypes annotations not to include in the encoding. For example, if
+   *     {@code com.example.Nullable} is in this set then the encoding will not include this
+   *     {@code @Nullable} annotation.
+   */
+  private static String encodeWithAnnotations(
+      TypeMirror type,
+      ImmutableList<AnnotationMirror> extraAnnotations,
+      Set<TypeMirror> excludedAnnotationTypes) {
     StringBuilder sb = new StringBuilder();
-    return ANNOTATED_ENCODING_TYPE_VISITOR.visit2(type, sb).toString();
+    // A function that is equivalent to t.getAnnotationMirrors() except when the t in question is
+    // our starting type. In that case we also add extraAnnotations to the result.
+    Function<TypeMirror, List<? extends AnnotationMirror>> getTypeAnnotations =
+        t ->
+            (t == type)
+                ? ImmutableList.<AnnotationMirror>builder()
+                    .addAll(t.getAnnotationMirrors())
+                    .addAll(extraAnnotations)
+                    .build()
+                : t.getAnnotationMirrors();
+    return new AnnotatedEncodingTypeVisitor(excludedAnnotationTypes, getTypeAnnotations)
+        .visit2(type, sb)
+        .toString();
+  }
+
+  /**
+   * Encodes the given type and its type annotations. The class comment for {@link TypeEncoder}
+   * covers the details of annotation encoding.
+   *
+   * @param extraAnnotations additional type annotations to include with the type
+   * @param excludedAnnotationTypes annotations not to include in the encoding. For example, if
+   *     {@code com.example.Nullable} is in this set then the encoding will not include this
+   *     {@code @Nullable} annotation.
+   */
+  static String encodeWithAnnotations(
+      AnnotatedTypeMirror type,
+      ImmutableList<AnnotationMirror> extraAnnotations,
+      Set<TypeMirror> excludedAnnotationTypes) {
+    StringBuilder sb = new StringBuilder();
+    // A function that is equivalent to t.getAnnotationMirrors() except when the t in question is
+    // our starting type. In that case we also add extraAnnotations to the result.
+    Function<TypeMirror, List<? extends AnnotationMirror>> getTypeAnnotations =
+        t ->
+            (t == type.getType())
+                ? ImmutableList.<AnnotationMirror>builder()
+                    .addAll(type.annotations())
+                    .addAll(extraAnnotations)
+                    .build()
+                : t.getAnnotationMirrors();
+    return new AnnotatedEncodingTypeVisitor(excludedAnnotationTypes, getTypeAnnotations)
+        .visit2(type.getType(), sb)
+        .toString();
   }
 
   /**
@@ -132,10 +222,11 @@ final class TypeEncoder {
   }
 
   /**
-   * Returns the formal type parameters of the given type. If we have {@code @AutoValue abstract
-   * class Foo<T extends SomeClass>} then this method will return an encoding of {@code <T extends
-   * SomeClass>} for {@code Foo}. Likewise it will return an encoding of the angle-bracket part of:
-   * <br>
+   * Returns a string representing the given type parameters as they would appear in a class
+   * declaration. For example, if we have {@code @AutoValue abstract class Foo<T extends SomeClass>}
+   * then if we call {@link TypeElement#getTypeParameters()} on the representation of {@code Foo},
+   * this method will return an encoding of {@code <T extends SomeClass>}. Likewise it will return
+   * an encoding of the angle-bracket part of: <br>
    * {@code Foo<SomeClass>}<br>
    * {@code Foo<T extends Number>}<br>
    * {@code Foo<E extends Enum<E>>}<br>
@@ -148,8 +239,7 @@ final class TypeEncoder {
    * {@code <E extends `java.lang.Enum`<E>>}<br>
    * {@code <K, V extends `java.lang.Comparable`<? extends K>>}.
    */
-  static String formalTypeParametersString(TypeElement type) {
-    List<? extends TypeParameterElement> typeParameters = type.getTypeParameters();
+  static String typeParametersString(List<? extends TypeParameterElement> typeParameters) {
     if (typeParameters.isEmpty()) {
       return "";
     } else {
@@ -170,14 +260,21 @@ final class TypeEncoder {
     sb.append(typeParameter.getSimpleName());
     String sep = " extends ";
     for (TypeMirror bound : typeParameter.getBounds()) {
-      if (!bound.toString().equals("java.lang.Object")) {
+      if (!isUnannotatedJavaLangObject(bound)) {
         sb.append(sep);
         sep = " & ";
-        sb.append(encode(bound));
+        sb.append(encodeWithAnnotations(bound));
       }
     }
   }
 
+  // We can omit "extends Object" from a type bound, but not "extends @NullableType Object".
+  private static boolean isUnannotatedJavaLangObject(TypeMirror type) {
+    return type.getKind().equals(TypeKind.DECLARED)
+        && type.getAnnotationMirrors().isEmpty()
+        && MoreTypes.asTypeElement(type).getQualifiedName().contentEquals("java.lang.Object");
+  }
+
   private static void appendAnnotations(
       List<? extends AnnotationMirror> annotationMirrors, StringBuilder sb) {
     for (AnnotationMirror annotationMirror : annotationMirrors) {
@@ -219,13 +316,25 @@ final class TypeEncoder {
 
     @Override
     public StringBuilder visitDeclared(DeclaredType type, StringBuilder sb) {
-      sb.append(declaredTypeName(type));
+      appendTypeName(type, sb);
       appendTypeArguments(type, sb);
       return sb;
     }
 
-    String declaredTypeName(DeclaredType type) {
-      return "`" + className(type) + "`";
+    void appendTypeName(DeclaredType type, StringBuilder sb) {
+      TypeMirror enclosing = EclipseHack.getEnclosingType(type);
+      if (enclosing.getKind().equals(TypeKind.DECLARED)) {
+        // We might have something like com.example.Outer<Double>.Inner. We need to encode
+        // com.example.Outer<Double> first, producing `com.example.Outer`<`java.lang.Double`>.
+        // Then we can simply add .Inner after that. If Inner has its own type arguments, we'll
+        // add them with appendTypeArguments below. Of course, it's more usual for the outer class
+        // not to have type arguments, but we'll still follow this path if the nested class is an
+        // inner (not static) class.
+        visit2(enclosing, sb);
+        sb.append(".").append(type.asElement().getSimpleName());
+      } else {
+        sb.append('`').append(className(type)).append('`');
+      }
     }
 
     void appendTypeArguments(DeclaredType type, StringBuilder sb) {
@@ -259,7 +368,7 @@ final class TypeEncoder {
 
     @Override
     public StringBuilder visitError(ErrorType t, StringBuilder p) {
-      throw new MissingTypeException();
+      throw new MissingTypeException(t);
     }
   }
 
@@ -275,9 +384,34 @@ final class TypeEncoder {
    * `java.util.List`} form.
    */
   private static class AnnotatedEncodingTypeVisitor extends EncodingTypeVisitor {
+    private final Set<TypeMirror> excludedAnnotationTypes;
+    private final Function<TypeMirror, List<? extends AnnotationMirror>> getTypeAnnotations;
+
+    AnnotatedEncodingTypeVisitor(
+        Set<TypeMirror> excludedAnnotationTypes,
+        Function<TypeMirror, List<? extends AnnotationMirror>> getTypeAnnotations) {
+      this.excludedAnnotationTypes = excludedAnnotationTypes;
+      this.getTypeAnnotations = getTypeAnnotations;
+    }
+
+    private void appendAnnotationsWithExclusions(
+        List<? extends AnnotationMirror> annotations, StringBuilder sb) {
+      // Optimization for the very common cases where there are no annotations or there are no
+      // exclusions.
+      if (annotations.isEmpty() || excludedAnnotationTypes.isEmpty()) {
+        appendAnnotations(annotations, sb);
+        return;
+      }
+      List<AnnotationMirror> includedAnnotations =
+          annotations.stream()
+              .filter(a -> !excludedAnnotationTypes.contains(a.getAnnotationType()))
+              .collect(toList());
+      appendAnnotations(includedAnnotations, sb);
+    }
+
     @Override
     public StringBuilder visitPrimitive(PrimitiveType type, StringBuilder sb) {
-      appendAnnotations(type.getAnnotationMirrors(), sb);
+      appendAnnotationsWithExclusions(getTypeAnnotations.apply(type), sb);
       // We can't just append type.toString(), because that will also have the annotation, but
       // without encoding.
       return sb.append(type.getKind().toString().toLowerCase());
@@ -285,7 +419,7 @@ final class TypeEncoder {
 
     @Override
     public StringBuilder visitTypeVariable(TypeVariable type, StringBuilder sb) {
-      appendAnnotations(type.getAnnotationMirrors(), sb);
+      appendAnnotationsWithExclusions(getTypeAnnotations.apply(type), sb);
       return sb.append(type.asElement().getSimpleName());
     }
 
@@ -297,27 +431,44 @@ final class TypeEncoder {
     @Override
     public StringBuilder visitArray(ArrayType type, StringBuilder sb) {
       visit2(type.getComponentType(), sb);
-      List<? extends AnnotationMirror> annotationMirrors = type.getAnnotationMirrors();
+      List<? extends AnnotationMirror> annotationMirrors = getTypeAnnotations.apply(type);
       if (!annotationMirrors.isEmpty()) {
         sb.append(" ");
-        appendAnnotations(annotationMirrors, sb);
+        appendAnnotationsWithExclusions(annotationMirrors, sb);
       }
       return sb.append("[]");
     }
 
     @Override
     public StringBuilder visitDeclared(DeclaredType type, StringBuilder sb) {
-      List<? extends AnnotationMirror> annotationMirrors = type.getAnnotationMirrors();
+      List<? extends AnnotationMirror> annotationMirrors = getTypeAnnotations.apply(type);
       if (annotationMirrors.isEmpty()) {
-        sb.append(declaredTypeName(type));
+        super.visitDeclared(type, sb);
       } else {
-        String className = className(type);
-        // See the class doc comment for an explanation of « and » here.
-        sb.append("`«").append(className).append("`");
-        appendAnnotations(annotationMirrors, sb);
-        sb.append("`»").append(className).append("`");
+        TypeMirror enclosing = EclipseHack.getEnclosingType(type);
+        if (enclosing.getKind().equals(TypeKind.DECLARED)) {
+          // We have something like com.example.Outer<Double>.@Annot Inner.
+          // We'll recursively encode com.example.Outer<Double> first,
+          // which if it is also annotated might result in a mouthful like
+          // `«com.example.Outer`@`org.annots.Nullable``»com.example.Outer`<`java.lang.Double`> .
+          // That annotation will have been added by a recursive call to this method.
+          // Then we'll add the annotation on the .Inner class, which we know is there because
+          // annotationMirrors is not empty. That means we'll append .@`org.annots.Annot` Inner .
+          visit2(enclosing, sb);
+          sb.append(".");
+          appendAnnotationsWithExclusions(annotationMirrors, sb);
+          sb.append(type.asElement().getSimpleName());
+        } else {
+          // This isn't an inner class, so we have the simpler (but still complicated) case of
+          // needing to place the annotation correctly in cases like java.util.@Nullable Map .
+          // See the class doc comment for an explanation of « and » here.
+          String className = className(type);
+          sb.append("`«").append(className).append("`");
+          appendAnnotationsWithExclusions(annotationMirrors, sb);
+          sb.append("`»").append(className).append("`");
+        }
+        appendTypeArguments(type, sb);
       }
-      appendTypeArguments(type, sb);
       return sb;
     }
   }
